SystemOrganization addCategory: #ConfigurationOfPharoSound!

Object subclass: #ConfigurationOfPharoSound
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfPharoSound'!

!ConfigurationOfPharoSound class methodsFor: 'private' stamp: 'MarianoMartinezPeck 12/18/2009 12:00'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfPharoSound class methodsFor: 'private' stamp: 'DaleHenrichs 12/29/2009 17:56'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load latest version of Metacello, load a specific version if desired"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #loadLatestVersion ]! !

!ConfigurationOfPharoSound class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 12/18/2009 12:00'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfPharoSound class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 12/18/2009 12:00'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfPharoSound class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 12/18/2009 12:00'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfPharoSound class methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 12/18/2009 12:00'!
project

	^self new project! !

!ConfigurationOfPharoSound methodsFor: 'baselines' stamp: 'GuillermoPolito 2/18/2011 22:18'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/PharoSound'.
		spec 
			package: 'Sound';
			package: 'SoundMorphicUserInterface' with: [ spec requires: 'Sound'].
			
	]! !

!ConfigurationOfPharoSound methodsFor: 'baselines' stamp: 'MarianoMartinezPeck 4/4/2010 19:37'!
baseline20: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/PharoNonCorePackages'.
		spec 
			package: 'Sound';
			package: 'SoundMorphicUserInterface' with: [ spec requires: 'Sound' ].
			
	]! !

!ConfigurationOfPharoSound methodsFor: 'baselines' stamp: 'GuillermoPolito 2/18/2011 22:17'!
baseline30: spec 
	<version: '3.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/PharoSound'.
		spec 
			package: 'Sound';
			package: 'Collection-Arithmetic' with: [ spec repository: 'http://www.squeaksource.com/CollectionArithmetic' ];
			package: 'SoundMorphicUserInterface' with: [ spec requires: 'Sound'; requires: 'Collection-Arithmetic' ].
			
	]! !

!ConfigurationOfPharoSound methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 12/18/2009 12:00'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfPharoSound methodsFor: 'symbolic versions' stamp: 'GuillermoPolito 2/18/2011 01:22'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'pharo1.0.x' version: '1.0'. 
	spec for: #'pharo1.1.x' version: '3.0'. 
	spec for: #'pharo1.2.x' version: '3.0'. 
! !

!ConfigurationOfPharoSound methodsFor: 'versions' stamp: 'MarianoMartinezPeck 12/19/2009 21:23'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #release.
		spec author: 'MarianoMartinezPeck'.
		spec description: 'First release 1.0 of this project '.
	].
	
	spec for: #pharo do: [
		spec 
			package: 'Sound' with: 'Sound-StephaneDucasse.47';
			package: 'SoundMorphicUserInterface' with: 'SoundMorphicUserInterface-DamienCassou.6'.
			
	]		! !

!ConfigurationOfPharoSound methodsFor: 'versions' stamp: 'MarianoMartinezPeck 4/4/2010 19:38'!
version20: spec
	<version: '2.0' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #release.
		spec author: 'MarianoMartinezPeck'.
		spec description: '- Changed the repository.
		- Some fixes to work with Pharo 1.1  '.
	].
	
	spec for: #pharo do: [
		spec 
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.49';
			package: 'SoundMorphicUserInterface' with: 'SoundMorphicUserInterface-MarianoMartinezPeck.9'.
			
	]		! !

!ConfigurationOfPharoSound methodsFor: 'versions' stamp: 'GuillermoPolito 2/18/2011 22:18'!
version30: spec
	<version: '3.0' imports: #('3.0-baseline')>

	spec for: #common do: [
		spec blessing: #development.
		spec author: 'MarianoMartinezPeck'.
		spec description: '- Changed the repository.
		- Some fixes to work with Pharo 1.1  '.
	].
	
	spec for: #pharo do: [
		spec 
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'Collection-Arithmetic' with: 'Collections-Arithmetic-HenrikSperreJohansen.2';
			package: 'SoundMorphicUserInterface' with: 'SoundMorphicUserInterface-HenrikSperreJohansen.19'.
			
	]		! !
